@@ -18,12 +18,6 @@ class KRunUnitTest : public QObject
 private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
-    void testExecutableName_data();
-    void testExecutableName();
-    void testProcessDesktopExec();
-    void testProcessDesktopExecNoFile_data();
-    void testProcessDesktopExecNoFile();
-    void testKtelnetservice();
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
     void testMimeTypeFile();
