@@ -15,7 +15,6 @@
 #include <KLocalizedString>
 #include <KStringHandler>
 
-#include "scheduler.h"
 #include "slave.h"
 #include <kio/jobuidelegateextension.h>
 
@@ -108,6 +107,14 @@ void JobPrivate::emitMoving(KIO::Job *job, const QUrl &src, const QUrl &dest)
     Q_EMIT job->description(job, s_title, qMakePair(s_source, url_description_string(src)), qMakePair(s_destination, url_description_string(dest)));
 }
 
+void JobPrivate::emitRenaming(KIO::Job *job, const QUrl &src, const QUrl &dest)
+{
+    static const QString s_title = i18nc("@title job", "Renaming");
+    static const QString s_source = i18nc("The source of a file operation", "Source");
+    static const QString s_destination = i18nc("The destination of a file operation", "Destination");
+    Q_EMIT job->description(job, s_title, {s_source, url_description_string(src)}, {s_destination, url_description_string(dest)});
+}
+
 void JobPrivate::emitCopying(KIO::Job *job, const QUrl &src, const QUrl &dest)
 {
     static const QString s_title = i18nc("@title job", "Copying");
@@ -154,11 +161,6 @@ void JobPrivate::emitUnmounting(KIO::Job *job, const QString &point)
     Q_EMIT job->description(job, i18nc("@title job", "Unmounting"), qMakePair(i18n("Mountpoint"), point));
 }
 
-void JobPrivate::setTransient(KIO::Job *job, bool transient)
-{
-    job->setProperty("transientProgressReporting", transient);
-}
-
 bool Job::doKill()
 {
     // kill all subjobs, without triggering their result slot
@@ -266,49 +268,49 @@ QByteArray JobPrivate::privilegeOperationData()
             status = OperationAllowed;
             switch (m_operationType) {
             case ChangeAttr:
-                m_caption = i18n("Change Attribute");
+                m_title = i18n("Change Attribute");
                 m_message = i18n(
                     "Root privileges are required to change file attributes. "
                     "Do you want to continue?");
                 break;
             case Copy:
-                m_caption = i18n("Copy Files");
+                m_title = i18n("Copy Files");
                 m_message = i18n(
                     "Root privileges are required to complete the copy operation. "
                     "Do you want to continue?");
                 break;
             case Delete:
-                m_caption = i18n("Delete Files");
+                m_title = i18n("Delete Files");
                 m_message = i18n(
                     "Root privileges are required to complete the delete operation. "
                     "However, doing so may damage your system. Do you want to continue?");
                 break;
             case MkDir:
-                m_caption = i18n("Create Folder");
+                m_title = i18n("Create Folder");
                 m_message = i18n(
                     "Root privileges are required to create this folder. "
                     "Do you want to continue?");
                 break;
             case Move:
-                m_caption = i18n("Move Items");
+                m_title = i18n("Move Items");
                 m_message = i18n(
                     "Root privileges are required to complete the move operation. "
                     "Do you want to continue?");
                 break;
             case Rename:
-                m_caption = i18n("Rename");
+                m_title = i18n("Rename");
                 m_message = i18n(
                     "Root privileges are required to complete renaming. "
                     "Do you want to continue?");
                 break;
             case Symlink:
-                m_caption = i18n("Create Symlink");
+                m_title = i18n("Create Symlink");
                 m_message = i18n(
                     "Root privileges are required to create a symlink. "
                     "Do you want to continue?");
                 break;
             case Transfer:
-                m_caption = i18n("Transfer data");
+                m_title = i18n("Transfer data");
                 m_message = i18n(
                     "Root privileges are required to complete transferring data. "
                     "Do you want to continue?");
@@ -326,7 +328,7 @@ QByteArray JobPrivate::privilegeOperationData()
 
     QByteArray parentJobData;
     QDataStream ds(&parentJobData, QIODevice::WriteOnly);
-    ds << status << m_caption << m_message;
+    ds << status << m_title << m_message;
     return parentJobData;
 }
 
