@@ -14,6 +14,7 @@
 #include <config-kmountpoint.h>
 #include <kioglobal_p.h> // Defines QT_LSTAT on windows to kio_windows_lstat
 
+#include <QDebug>
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -469,7 +470,7 @@ bool KMountPoint::probablySlow() const
     return isOnNetwork()
         || d->m_mountType == QLatin1String("autofs")
         || d->m_mountType == QLatin1String("subfs")
-        // Technically KIOFUSe mounts local slaves as well,
+        // Technically KIOFUSe mounts local workers as well,
         // such as recents:/, but better safe than sorry...
         || d->m_mountType == QLatin1String("fuse.kio-fuse");
     /* clang-format on */
@@ -505,3 +506,23 @@ bool KMountPoint::testFileSystemFlag(FileSystemFlag flag) const
     }
     return false;
 }
+
+KIOCORE_EXPORT QDebug operator<<(QDebug debug, const KMountPoint::Ptr &mp)
+{
+    QDebugStateSaver saver(debug);
+    if (!mp) {
+        debug << "QDebug operator<< called on a null KMountPoint::Ptr";
+        return debug;
+    }
+
+    // clang-format off
+    debug.nospace() << "KMountPoint ["
+                    << "Mounted from: "  << mp->d->m_mountedFrom
+                    << ", device name: " << mp->d->m_device
+                    << ", mount point: " << mp->d->m_mountPoint
+                    << ", mount type: "  << mp->d->m_mountType
+                    <<']';
+
+    // clang-format on
+    return debug;
+}
