@@ -1,42 +1,30 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2007, 2008, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007, 2008, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "ksslcertificatemanager.h"
 #include "ksslcertificatemanager_p.h"
 #include "ksslerror_p.h"
 
-#include "ktcpsocket.h"
+#include "kssld_interface.h"
 #include "ksslerroruidata_p.h"
+
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 
-#include <QDebug>
-#include <QStandardPaths>
-#include <QFile>
-#include <QDir>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QDebug>
+#include <QDir>
+#include <QFile>
 #include <QSslConfiguration>
+#include <QStandardPaths>
 
-#include "kssld_interface.h"
+#include <set>
 
 /*
   Config file format:
@@ -72,10 +60,7 @@ KSslCertificateRule::KSslCertificateRule(const KSslCertificateRule &other)
     *d = *other.d;
 }
 
-KSslCertificateRule::~KSslCertificateRule()
-{
-    delete d;
-}
+KSslCertificateRule::~KSslCertificateRule() = default;
 
 KSslCertificateRule &KSslCertificateRule::operator=(const KSslCertificateRule &other)
 {
@@ -129,7 +114,7 @@ bool KSslCertificateRule::isErrorIgnored(QSslError::SslError error) const
 void KSslCertificateRule::setIgnoredErrors(const QList<KSslError::Error> &errors)
 {
     d->ignoredErrors.clear();
-    //### Quadratic runtime, woohoo! Use a QSet if that should ever be an issue.
+    // ### Quadratic runtime, woohoo! Use a QSet if that should ever be an issue.
     for (KSslError::Error e : errors) {
         QSslError::SslError error = KSslErrorPrivate::errorFromKSslError(e);
         if (!isErrorIgnored(error)) {
@@ -228,12 +213,12 @@ QList<QSslError> KSslCertificateRule::filterErrors(const QList<QSslError> &error
 
 static QList<QSslCertificate> deduplicate(const QList<QSslCertificate> &certs)
 {
-    QSet<QByteArray> digests;
+    std::set<QByteArray> digests;
     QList<QSslCertificate> ret;
     for (const QSslCertificate &cert : certs) {
         QByteArray digest = cert.digest();
-        if (!digests.contains(digest)) {
-            digests.insert(digest);
+        const auto [it, isInserted] = digests.insert(digest);
+        if (isInserted) {
             ret.append(cert);
         }
     }
@@ -241,12 +226,10 @@ static QList<QSslCertificate> deduplicate(const QList<QSslCertificate> &certs)
 }
 
 KSslCertificateManagerPrivate::KSslCertificateManagerPrivate()
-    : config(QStringLiteral("ksslcertificatemanager"), KConfig::SimpleConfig),
-      iface(new org::kde::KSSLDInterface(QStringLiteral("org.kde.kssld5"),
-                                         QStringLiteral("/modules/kssld"),
-                                         QDBusConnection::sessionBus())),
-      isCertListLoaded(false),
-      userCertDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kssl/userCaCertificates/"))
+    : config(QStringLiteral("ksslcertificatemanager"), KConfig::SimpleConfig)
+    , iface(new org::kde::KSSLDInterface(QStringLiteral("org.kde.kssld5"), QStringLiteral("/modules/kssld"), QDBusConnection::sessionBus()))
+    , isCertListLoaded(false)
+    , userCertDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kssl/userCaCertificates/"))
 {
 }
 
@@ -265,14 +248,9 @@ void KSslCertificateManagerPrivate::loadDefaultCaCertificates()
     KConfig config(QStringLiteral("ksslcablacklist"), KConfig::SimpleConfig);
     KConfigGroup group = config.group("Blacklist of CA Certificates");
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-    certs.append(QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
-                                           QSslCertificate::PatternSyntax::Wildcard));
-#else
-    certs.append(QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
-                                           QRegExp::Wildcard));
-#endif
-    for (const QSslCertificate &cert : qAsConst(certs)) {
+    certs.append(QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem, QSslCertificate::PatternSyntax::Wildcard));
+
+    for (const QSslCertificate &cert : std::as_const(certs)) {
         const QByteArray digest = cert.digest().toHex();
         if (!group.hasKey(digest.constData())) {
             defaultCaCertificates += cert;
@@ -284,7 +262,7 @@ void KSslCertificateManagerPrivate::loadDefaultCaCertificates()
 
 bool KSslCertificateManagerPrivate::addCertificate(const KSslCaCertificate &in)
 {
-    //qDebug() << Q_FUNC_INFO;
+    // qDebug() << Q_FUNC_INFO;
     // cannot add a certificate to the system store
     if (in.store == KSslCaCertificate::SystemStore) {
         Q_ASSERT(false);
@@ -316,7 +294,7 @@ bool KSslCertificateManagerPrivate::addCertificate(const KSslCaCertificate &in)
 
 bool KSslCertificateManagerPrivate::removeCertificate(const KSslCaCertificate &old)
 {
-    //qDebug() << Q_FUNC_INFO;
+    // qDebug() << Q_FUNC_INFO;
     // cannot remove a certificate from the system store
     if (old.store == KSslCaCertificate::SystemStore) {
         Q_ASSERT(false);
@@ -324,7 +302,6 @@ bool KSslCertificateManagerPrivate::removeCertificate(const KSslCaCertificate &o
     }
 
     if (!QFile::remove(userCertDir + QString::fromLatin1(old.certHash))) {
-
         // suppose somebody copied a certificate file into userCertDir without changing the
         // filename to the digest.
         // the rest of the code will work fine because it loads all certificate files from
@@ -420,20 +397,14 @@ void KSslCertificateManagerPrivate::setAllCertificates(const QList<KSslCaCertifi
 
 QList<KSslCaCertificate> KSslCertificateManagerPrivate::allCertificates() const
 {
-    //qDebug() << Q_FUNC_INFO;
+    // qDebug() << Q_FUNC_INFO;
     QList<KSslCaCertificate> ret;
     const QList<QSslCertificate> list = deduplicate(QSslConfiguration::systemCaCertificates());
     for (const QSslCertificate &cert : list) {
         ret += KSslCaCertificate(cert, KSslCaCertificate::SystemStore, false);
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-    const QList<QSslCertificate> userList = QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
-                                                                   QSslCertificate::PatternSyntax::Wildcard);
-#else
-    const QList<QSslCertificate> userList = QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
-                                                                   QRegExp::Wildcard);
-#endif
+    const QList<QSslCertificate> userList = QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem, QSslCertificate::PatternSyntax::Wildcard);
     for (const QSslCertificate &cert : userList) {
         ret += KSslCaCertificate(cert, KSslCaCertificate::UserStore, false);
     }
@@ -443,7 +414,7 @@ QList<KSslCaCertificate> KSslCertificateManagerPrivate::allCertificates() const
     for (KSslCaCertificate &cert : ret) {
         if (group.hasKey(cert.certHash.constData())) {
             cert.isBlacklisted = true;
-            //qDebug() << "is blacklisted";
+            // qDebug() << "is blacklisted";
         }
     }
 
@@ -455,10 +426,9 @@ bool KSslCertificateManagerPrivate::updateCertificateBlacklisted(const KSslCaCer
     return setCertificateBlacklisted(cert.certHash, cert.isBlacklisted);
 }
 
-bool KSslCertificateManagerPrivate::setCertificateBlacklisted(const QByteArray &certHash,
-        bool isBlacklisted)
+bool KSslCertificateManagerPrivate::setCertificateBlacklisted(const QByteArray &certHash, bool isBlacklisted)
 {
-    //qDebug() << Q_FUNC_INFO << isBlacklisted;
+    // qDebug() << Q_FUNC_INFO << isBlacklisted;
     KConfig config(QStringLiteral("ksslcablacklist"), KConfig::SimpleConfig);
     KConfigGroup group = config.group("Blacklist of CA Certificates");
     if (isBlacklisted) {
@@ -487,12 +457,9 @@ KSslCertificateManager::KSslCertificateManager()
 {
 }
 
-KSslCertificateManager::~KSslCertificateManager()
-{
-    delete d;
-}
+KSslCertificateManager::~KSslCertificateManager() = default;
 
-//static
+// static
 KSslCertificateManager *KSslCertificateManager::self()
 {
     return &g_instance()->sslCertificateManager;
@@ -513,8 +480,7 @@ void KSslCertificateManager::clearRule(const QSslCertificate &cert, const QStrin
     d->iface->clearRule(cert, hostName);
 }
 
-KSslCertificateRule KSslCertificateManager::rule(const QSslCertificate &cert,
-        const QString &hostName) const
+KSslCertificateRule KSslCertificateManager::rule(const QSslCertificate &cert, const QString &hostName) const
 {
     return d->iface->rule(cert, hostName);
 }
@@ -529,7 +495,7 @@ QList<QSslCertificate> KSslCertificateManager::caCertificates() const
 }
 
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
-//static
+// static
 QList<KSslError> KSslCertificateManager::nonIgnorableErrors(const QList<KSslError> &errors)
 {
     QList<KSslError> ret;
@@ -542,7 +508,7 @@ QList<KSslError> KSslCertificateManager::nonIgnorableErrors(const QList<KSslErro
 #endif
 
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
-//static
+// static
 QList<KSslError::Error> KSslCertificateManager::nonIgnorableErrors(const QList<KSslError::Error> &errors)
 {
     QList<KSslError::Error> ret;
