@@ -9,7 +9,9 @@
 
 #include "kiofilewidgets_export.h"
 #include <QDialog>
-class KLineEdit;
+
+#include <memory>
+
 class KUrlRequester;
 class KNameAndUrlInputDialogPrivate;
 class QUrl;
@@ -17,7 +19,7 @@ class QUrl;
 /**
  * @class KNameAndUrlInputDialog knameandurlinputdialog.h <KNameAndUrlInputDialog>
  *
- * Dialog to ask for a name (e.g. filename) and a URL
+ * Dialog to ask for a name (e.g.\ filename) and a URL
  * Basically a merge of KLineEditDlg and KUrlRequesterDlg ;)
  * @since 4.5
  * @author David Faure <faure@kde.org>
@@ -37,7 +39,7 @@ public:
     /**
      * Destructor.
      */
-    virtual ~KNameAndUrlInputDialog();
+    ~KNameAndUrlInputDialog() override;
 
     /**
      * Pre-fill the name lineedit.
@@ -64,10 +66,7 @@ public:
     QString urlText() const;
 
 private:
-    Q_PRIVATE_SLOT(d, void _k_slotNameTextChanged(const QString &))
-    Q_PRIVATE_SLOT(d, void _k_slotURLTextChanged(const QString &))
-
-    KNameAndUrlInputDialogPrivate *const d;
+    std::unique_ptr<KNameAndUrlInputDialogPrivate> const d;
 };
 
 #endif
