@@ -17,6 +17,7 @@
 #include "kiogui_debug.h"
 
 #include "desktopexecparser.h"
+#include "gpudetection_p.h"
 #include "krecentdocument.h"
 #include <KDesktopFile>
 #include <KLocalizedString>
@@ -65,6 +66,16 @@ static KProcessRunner *makeInstance()
     return new ForkingProcessRunner();
 }
 
+static void modifyEnv(KProcess &process, QProcessEnvironment mod)
+{
+    QProcessEnvironment env = process.processEnvironment();
+    if (env.isEmpty()) {
+        env = QProcessEnvironment::systemEnvironment();
+    }
+    env.insert(mod);
+    process.setProcessEnvironment(env);
+}
+
 KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
                                                 const QString &serviceEntryPath,
                                                 const QList<QUrl> &urls,
@@ -109,28 +120,8 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
     *instance->m_process << args;
 
 #ifndef Q_OS_ANDROID
-    enum DiscreteGpuCheck { NotChecked, Present, Absent };
-    static DiscreteGpuCheck s_gpuCheck = NotChecked;
-
-    if (service->runOnDiscreteGpu() && s_gpuCheck == NotChecked) {
-        // Check whether we have a discrete gpu
-        bool hasDiscreteGpu = false;
-        QDBusInterface iface(QStringLiteral("org.kde.Solid.PowerManagement"),
-                             QStringLiteral("/org/kde/Solid/PowerManagement"),
-                             QStringLiteral("org.kde.Solid.PowerManagement"),
-                             QDBusConnection::sessionBus());
-        if (iface.isValid()) {
-            QDBusReply<bool> reply = iface.call(QStringLiteral("hasDualGpu"));
-            if (reply.isValid()) {
-                hasDiscreteGpu = reply.value();
-            }
-        }
-
-        s_gpuCheck = hasDiscreteGpu ? Present : Absent;
-    }
-
-    if (service->runOnDiscreteGpu() && s_gpuCheck == Present) {
-        instance->m_process->setEnv(QStringLiteral("DRI_PRIME"), QStringLiteral("1"));
+    if (service->runOnDiscreteGpu()) {
+        modifyEnv(*instance->m_process, KIO::discreteGpuEnvironment());
     }
 #endif
 
@@ -310,7 +301,7 @@ void KProcessRunner::init(const KService::Ptr &service,
                                     m_waitingForXdgToken = false;
                                 }
                             });
-                    KWindowSystem::requestXdgActivationToken(window, launchedSerial, QFileInfo(m_serviceEntryPath).completeBaseName());
+                    KWindowSystem::requestXdgActivationToken(window, launchedSerial, maybeAliasedName(QFileInfo(m_serviceEntryPath).completeBaseName()));
                 }
             }
         }
@@ -472,9 +463,8 @@ void ForkingProcessRunner::slotProcessExited(int exitCode, QProcess::ExitStatus
     if (exitCode == 9009) {
 #endif
         const QStringList args = m_cmd.split(QLatin1Char(' '));
-        Q_EMIT error(xi18nc("@info", "The command <command>%1</command> could not be found.", args[0]));
+        emitDelayedError(xi18nc("@info", "The command <command>%1</command> could not be found.", args[0]));
     }
-    Q_EMIT processFinished();
 }
 
 // This code is also used in klauncher (and KRun).
@@ -521,3 +511,5 @@ ForkingProcessRunner::ForkingProcessRunner()
     : KProcessRunner()
 {
 }
+
+#include "moc_kprocessrunner_p.cpp"
