@@ -15,6 +15,8 @@
 
 #include "kiowidgets_export.h"
 
+#include <memory>
+
 #ifdef Q_OS_UNIX
 
 class KJob;
@@ -23,6 +25,8 @@ namespace KIO
 class Job;
 }
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 88)
+
 class KAutoMountPrivate;
 /**
  * @class KAutoMount kautomount.h <KAutoMount>
@@ -33,6 +37,8 @@ class KAutoMountPrivate;
  * used by KDesktopFileActions.
  *
  * @short This class implements synchronous mounting of devices.
+ *
+ * @deprecated Since 5.88. There's no direct replacement, Solid::StorageAccess::setup may help
  */
 class KIOWIDGETS_EXPORT KAutoMount : public QObject
 {
@@ -49,8 +55,13 @@ public:
      * @param show_filemanager_window if true, a file-manager window for that mountpoint is shown after
      * the mount, if successful.
      */
-    KAutoMount(bool readonly, const QByteArray &format, const QString &device, const QString &mountpoint,
-               const QString &desktopFile, bool show_filemanager_window = true);
+    KIOWIDGETS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
+    KAutoMount(bool readonly,
+               const QByteArray &format,
+               const QString &device,
+               const QString &mountpoint,
+               const QString &desktopFile,
+               bool show_filemanager_window = true);
 
 Q_SIGNALS:
     /** Emitted when the directory has been mounted */
@@ -60,10 +71,10 @@ Q_SIGNALS:
 
 private:
     /** KAutoMount deletes itself. Don't delete it manually. */
-    ~KAutoMount();
+    ~KAutoMount() override;
     Q_PRIVATE_SLOT(d, void slotResult(KJob *))
     friend class KAutoMountPrivate;
-    KAutoMountPrivate *const d;
+    std::unique_ptr<KAutoMountPrivate> const d;
 };
 
 class KAutoUnmountPrivate;
@@ -73,6 +84,8 @@ class KAutoUnmountPrivate;
  * used by KDesktopFileActions.
  *
  * @short This class implements synchronous unmounting of devices,
+ *
+ * @deprecated Since 5.88. There's no direct replacement, Solid::StorageAccess::teardown may help
  */
 class KIOWIDGETS_EXPORT KAutoUnmount : public QObject
 {
@@ -84,6 +97,7 @@ public:
      * @param desktopFile the file the user clicked on - to notify KDirWatch of the fact that
      * it should emit fileDirty for it (to have the icon change)
      */
+    KIOWIDGETS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     KAutoUnmount(const QString &mountpoint, const QString &desktopFile);
 
 Q_SIGNALS:
@@ -94,12 +108,13 @@ Q_SIGNALS:
 
 private:
     /** KAutoUnmount deletes itself. Don't delete it manually. */
-    ~KAutoUnmount();
+    ~KAutoUnmount() override;
     Q_PRIVATE_SLOT(d, void slotResult(KJob *))
     friend class KAutoUnmountPrivate;
-    KAutoUnmountPrivate *const d;
+    std::unique_ptr<KAutoUnmountPrivate> const d;
 };
+#endif
 
-#endif //Q_OS_UNIX
+#endif // Q_OS_UNIX
 
 #endif
