@@ -15,6 +15,8 @@
 #include <QList>
 #include <QUrl>
 
+#include <memory>
+
 namespace KIO
 {
 class OpenFileManagerWindowJobPrivate;
@@ -81,7 +83,10 @@ public:
     QByteArray startupId() const;
 
     /**
-     * Set the Startup ID
+     * Sets the platform-specific startup id of the file manager launch.
+     * @param startupId startup id, if any (otherwise "").
+     * For X11, this would be the id for the Startup Notification protocol.
+     * For Wayland, this would be the token for the XDG Activation protocol.
      */
     void setStartupId(const QByteArray &startupId);
 
@@ -95,7 +100,7 @@ private:
     friend class OpenFileManagerWindowDBusStrategy;
     friend class OpenFileManagerWindowKRunStrategy;
 
-    OpenFileManagerWindowJobPrivate *const d;
+    std::unique_ptr<OpenFileManagerWindowJobPrivate> const d;
 };
 
 /**
