@@ -131,13 +131,13 @@ RenameFileDialog::RenameFileDialog(const KFileItemList &items, QWidget *parent)
         QLabel *infoLabel = new QLabel(i18nc("@info", "# will be replaced by ascending numbers starting with:"), page);
         mainLayout->addWidget(infoLabel);
         d->spinBox = new QSpinBox(page);
-        d->spinBox->setMaximum(10000);
         d->spinBox->setMinimum(0);
+        d->spinBox->setMaximum(1'000'000'000);
         d->spinBox->setSingleStep(1);
         d->spinBox->setValue(1);
         d->spinBox->setDisplayIntegerBase(10);
 
-        QHBoxLayout *horizontalLayout = new QHBoxLayout(page);
+        QHBoxLayout *horizontalLayout = new QHBoxLayout;
         horizontalLayout->setContentsMargins(0, 0, 0, 0);
         horizontalLayout->addWidget(infoLabel);
         horizontalLayout->addWidget(d->spinBox);
@@ -222,3 +222,5 @@ void RenameFileDialog::slotResult(KJob *job)
 }
 
 } // namespace KIO
+
+#include "moc_renamefiledialog.cpp"
